@@ -1,5 +1,6 @@
 import os
 from pathlib import Path
+from typing import Iterable
 
 from colassigner.constants import PREFIX_SEP  # noqa: F401
 
@@ -26,13 +27,13 @@ CLI = "dz"
 
 CRON_ENV_VAR = "CRON_TRIGGER"
 GIT_TOKEN_ENV_VAR = "GIT_HTTPS_TOKEN"
-AUTH_ENV_VAR = "ZIMMER_FULL_AUTH"
+AUTH_HEX_ENV_VAR = "ZIMMER_AUTH_HEX"
+AUTH_PASS_ENV_VAR = "ZIMMER_PHRASE"
 
 VERSION_VAR_NAME = "__version__"
 
 
-def repo_link(slug):
-    return f"https://github.com/sscu-budapest/{slug}"
+repo_link = "https://github.com/sscu-budapest/{}".format
 
 
 TEMPLATE_REPO = os.environ.get("ZIMMER_TEMPLATE", repo_link("project-template"))
@@ -48,19 +49,18 @@ class RegistryPaths:
         package_name = get_package_name(name)
 
         self.index_dir = self.dir / "index"
-        self.dist_dir = self.index_dir / package_name
         self.info_yaml = self.info_yaml_of(name, version)
-        self.publish_paths = self._relpos([self.dist_dir, self.info_yaml])
-        self.dist_gitpath = f"index/{package_name}/{package_name}-{version}.tar.gz"
+        self.publish_paths = self._relpos([self.index_dir, self.info_yaml])
+        self.dist_gitpath = f"index/{package_name}-{version}.tar.gz"
 
     def info_yaml_of(self, name, version) -> Path:
         return self._info_dir / f"{name}-{version}.yaml"
 
     def ensure(self):
-        for d in [self.dist_dir, self._info_dir]:
+        for d in [self.index_dir, self._info_dir]:
             d.mkdir(exist_ok=True, parents=True)
 
-    def _relpos(self, dirlist):
+    def _relpos(self, dirlist: Iterable[Path]):
         return [d.relative_to(self.dir).as_posix() for d in dirlist]
 
 
