@@ -48,7 +48,7 @@ def publish_meta():
 
 @app.command()
 def update_registry():
-    get_runtime(True).registry.update()
+    Registry(Config.load()).update()
 
 
 @app.command()
@@ -95,9 +95,9 @@ def publish_data(validate: bool = False):
 
 
 @app.command()
-def build_meta():
+def build_meta(global_conf: bool = False):
     get_global_pipereg(reset=True)  # used when building meta from script
-    Registry(Config.load()).full_build()
+    Registry(Config.load()).full_build(global_conf)
     runtime = get_runtime(True)
     crons = set(filter(None, [s.cron for s in runtime.pipereg.steps]))
     if crons:
@@ -106,7 +106,7 @@ def build_meta():
 
 
 @app.command()
-def load_external_data(git_commit: bool = False):
+def load_external_data(git_commit: bool = False, env: str = None):
     """watch out, this deletes everything
 
     should probably be a bit more clever,
@@ -114,7 +114,7 @@ def load_external_data(git_commit: bool = False):
     """
     runtime = get_runtime(True)
     logger.info("loading external data", envs=runtime.data_to_load)
-    posixes = runtime.load_all_data()
+    posixes = runtime.load_all_data(env=env)
     if git_commit and posixes:
         git_run(add=["*.gitignore", *[f"{p}.dvc" for p in posixes]])
         if get_git_diffs(True):
@@ -161,7 +161,7 @@ def run(
     rconf = RunConfig(profile=profile)
     with rconf:
         logger.info("running repro", targets=targets, **asdict(rconf))
-        runs = dvc_repo.reproduce(targets=targets)
+        runs = dvc_repo.reproduce(targets=targets, pull=True)
     git_run(add=["dvc.yaml", "dvc.lock", BASE_CONF_PATH])
     if commit and get_git_diffs(True):
         now = dt.datetime.now().isoformat(" ", "minutes")
